geese function from package geepack.
This function is called in geepack.lgst.batch function to apply association test to all SNPs in the
genotype data.
geepack.lgst(snp, phen, test.dat, covar = NULL, model = "a")test.dat test.dat geepack.lgst.batch.
geepack.lgst function tests association between a dichtomous trait and a SNP from a dataset that contains phenotype, genotype and
pedigree data (test.dat), where the dataset needs to be ordered by famid.
Zeger, S.L. and Liang, K.Y. (1986) Longitudinal data analysis for discrete and continuous outcomes. Biometrics, 42 121--130.
Yan, J and Fine, J. (2004) Estimating equations for association structures. Stat Med, 23 859--874.
geese function from package geepack ## Not run:
# geepack.lgst(snp=data[,"rs123"],phen="CVD",test.dat=data,model="a",covar=c("age","sex"))
# ## End(Not run)
Run the code above in your browser using DataLab