Learn R Programming

GWAF (version 2.0)

geepack.lgst.batch.imputed: function to test genetic association between a dichotomous trait and a batch of imputed SNPs in families using Generalized Estimation Equation model

Description

Fit logistic regression via Generalized Estimation Equation (GEE) to test association between a dichotomous phenotype and all imputed SNPs in a genotype file in family data under additive genetic model. Each family is treated as a cluster, with independence working correlation matrix used in the robust variance estimator. This function applies the same trait-SNP association test to all SNPs in the imputed genotype data. The trait-SNP association test is carried out by geepack.lgst.imputed function where the geese function from package geepack is used.

Usage

geepack.lgst.batch.imputed(genfile, phenfile, pedfile, outfile, phen, 
covars = NULL, col.names = T, sep.ped = ",", sep.phe = ",", sep.gen = ",")

Arguments

Value

No value is returned. Instead, results are written to outfile.phenphenotype namesnpSNP nameNthe number of individuals in analysisNdthe number of individuals in affected sample in analysisAFimputed allele frequency of coded alleleAFdimputed allele frequency of coded allele in affected samplebetaregression coefficient of SNP covariatesestandard error of betaremarkwarning or additional information for the analysis, note that the genotype counts are based on rounded imputed genotypes; 'not converged' indicates the GEE analysis did not converge; 'logistic reg' indicates GEE model is replaced by logistic regression; 'exp count<5' 5="" indicates="" any="" expected="" count="" is="" less="" than="" in="" phenotype-genotype="" table;="" 'not="" converged="" and="" exp="" count<5',="" 'logistic="" reg="" &="" count<5'="" are="" noted="" similarly;="" 'collinearity'="" collinearity="" exists="" between="" snp="" some="" covariates<="" description="">pvalp-value of the association test based on chi-square statistic

Details

Similar to the details for geepack.lgst.batch but here the SNP data contains imputed genotypes (allele dosages) that are continuous and range from 0 to 2. In addition, the user-specified genetic model argument is not available.