cov.int).
The covariate for interaction (cov.int) can be SNP genotype (gene-gene interaction) or an environmental factor (gene-environment interaction). Only one
interaction term is allowed. When cov.int is dichotomous, stratified analyses can be requested by specifying sub="Y". The covariance between the main
effect (SNP) and the interaction effect is provided in the output when stratified analysis is not requested. Each family is treated as
a cluster, with independence working correlation matrix used in the robust variance estimator. The interaction
test is carried out by the geese function from package geepack. This function is called in geepack.lgst.int.batch function to apply interaction test to all SNPs in a
genotype file.
geepack.lgst.int(snp,phen,test.dat,covar,cov.int,sub="N")test.dat test.dat covar geepack.lgst.int.batch function.
geepack.lgst.int function tests gene-environment or gene-genn interaction between a dichtomous trait and a SNP
from a dataset that contains phenotype, genotype and pedigree data (test.dat), where the dataset needs to be ordered by famid. Please also see details in
details for geepack.lgst.int.batch function.
Zeger, S.L. and Liang, K.Y. (1986) Longitudinal data analysis for discrete and continuous outcomes. Biometrics, 42 121--130.
Yan, J and Fine, J. (2004) Estimating equations for association structures. Stat Med, 23 859--874.
geese function from package geepack ## Not run:
# geepack.lgst.int(snp=data[,"rs123"],phen="CVD",test.dat=data,covar=c("age",sex"),
# cov.int="sex",sub="Y")
# ## End(Not run)
Run the code above in your browser using DataLab