cov.int).
The covariate for interaction (cov.int) can be SNP genotype (gene-gene interaction) or an environmental factor (gene-environment interaction). Only one
interaction term is allowed. When cov.int is dichotomous, stratified analyses can be requested by specifying sub="Y". The covariance between the main
effect (SNP) and the interaction effect is provided in the output when stratified analysis is not requested. Each pedigree is treated as
a cluster with independence working correlation matrix used in the robust variance estimator.
This function applies the same interaction test to all SNPs in a genotype file.
The interaction test is carried out by geepack.lgst.int function from GWAF where the
the geese function from package geepack is used.
geepack.lgst.int.batch(genfile,phenfile,pedfile,outfile,phen,covars,cov.int,sub="N",
col.names=T,sep.ped=",",sep.phe=",",sep.gen=",")phenfile phenfile covars cov.int is dichotomous) outfile.
If stratified analyses are requested, the result file will include the following columns. Otherwise, cov_beta_snp_beta_int will be included instead of
the results from stratified analyses, that is, beta_snp_cov0, se_snp_cov0, pval_snp_cov0, beta_snp_cov1, se_snp_cov1,
and pval_snp_cov1.beta_snpbeta_snp not equal to zerocov.int level is 0beta_snp_cov0beta_snp_cov0 not equal to zerocov.int level is 1beta_snp_cov1beta_snp_cov1 not equal to zerobeta_intbeta_int not equal to zerogeepack.lgst.int.batch function first reads in and merges phenotype-covariates, genotype
and pedigree files, then tests gene-environment or gene-gen interaction for phen against all SNPs in genfile.
Only one interaction term is allowed, so is the covariate for interaction (cov.int). When cov.int is dichotomous, stratified analyses can be
requested by specifying sub="Y". The covariance between the main effect (SNP) and the interaction effect is
provided in the output when stratified analysis is not requested.
genfile contains unique individual id and genotype data, with the column names being "id" and SNP names.
For each genotyped SNP, the genotype data should be coded as 0, 1, 2 indicating the numbers of the coded alleles. The SNP names in genotype file should not have any
dash, '-' and other special characters(dots and underscores are OK). phenfile contains unique individual id,
phenotype and covariates data, with the column names being "id" and phenotype and
covaraite names. pedfile contains pedigree informaion, with the column names being
"famid","id","fa","mo","sex". In all files, missing value should be an empty space, except missing parental id in pedfile.
Only phenotypes with two categories are analyzed. A phenotype should be coded as
0 and 1, with 1 denoting affected and 0 unaffected. SNPs with low genotype counts
(especially minor allele homozygote) may be omitted or analyzed with logistic regression.
The geepack.lgst.int.batch function fits GEE model using each pedigree as a cluster
with geepack.lgst.int function from GWAF package and geese function from geepack package.
## Not run:
# geepack.lgst.int.batch(phenfile="simphen.csv",genfile="simgen.csv",pedfile="simped.csv",
# phen="CVD",outfile="simout.csv",covars=c("sex","age"),cov.int="age",
# sep.ped=",",sep.phe=",",sep.gen=",")
# ## End(Not run)
Run the code above in your browser using DataLab