cov.int).
The covariate for interaction (cov.int) can be SNP genotype (gene-gene interaction) or an environmental factor (gene-environment interaction). Only one
interaction term is allowed. When cov.int is dichotomous, stratified analyses can be requested by specifying sub="Y". The covariance between the main
effect (SNP) and the interaction effect is provided in the output when stratified analysis is not requested. Each family is treated as
a cluster, with independence working correlation matrix used in the robust variance estimator.
This function applies the same interaction test to all SNPs in the imputed genotype data.
The interaction test is carried out by geepack.lgst.int.imputed function from GWAF where the
the geese function from package geepack is used.
geepack.lgst.int.batch.imputed(genfile,phenfile,pedfile,outfile,phen,
covars,cov.int,sub="N",col.names=T,sep.ped=",",sep.phe=",",sep.gen=",")phenfile phenfile covars cov.int is dichotomous) outfile.
If stratified analyses are requested, the result file will include the following columns. Otherwise, cov_beta_snp_beta_int will be included instead of
the results from stratified analyses, that is, beta_snp_cov0, se_snp_cov0, pval_snp_cov0, beta_snp_cov1, se_snp_cov1,
and pval_snp_cov1.beta_snpbeta_snp not equal to zerocov.int level is 0beta_snp_cov0beta_snp_cov0 not equal to zerocov.int level is 1beta_snp_cov1beta_snp_cov1 not equal to zerobeta_intbeta_int not equal to zerogeepack.lgst.int.batch but here the SNP data contains imputed genotypes (allele dosages)
that are continuous and range from 0 to 2.
## Not run:
# geepack.lgst.int.batch.imputed(phenfile="simphen.csv",genfile="simgen.csv",
# pedfile="simped.csv",phen="CVD",outfile="simout.csv",covars=c("sex","age"),cov.int="sex",
# sub="Y",sep.ped=",",sep.phe=",",sep.gen=",")
# ## End(Not run)
Run the code above in your browser using DataLab