Learn R Programming

GWAF (version 2.2)

geepack.lgst.int.imputed: function for testing gene-environment or gene-gene interaction between a dichotomous trait and an imputed SNP in family data using Generalized Estimation Equation model

Description

Fit logistic regression via Generalized Estimation Equation (GEE) to test gene-environment or gene-gene interaction between a dichotomous phenotype and one imputed SNP in a genotype file under additive genetic model. The interaction term is the product of SNP genotype and a covariate for interaction (cov.int). The covariate for interaction (cov.int) can be SNP genotype (gene-gene interaction) or an environmental factor (gene-environment interaction). Only one interaction term is allowed. When cov.int is dichotomous, stratified analyses can be requested by specifying sub="Y". The covariance between the main effect (SNP) and the interaction effect is provided in the output when stratified analysis is not requested. Each family is treated as a cluster, with independence working correlation matrix used in the robust variance estimator. This function is called in geepack.lgst.int.batch.imputed function to apply interaction test to all imputed SNPs in a genotype file. The interaction test is carried out by the geese function from package geepack.

Usage

geepack.lgst.int.imputed(snp,phen,test.dat,covar,cov.int,sub="N")

Arguments

snp
genotype data of a SNP
phen
a character string for a phenotype name in test.dat
test.dat
the product of merging phenotype, genotype and pedigree data, should be ordered by "famid"
covar
a character vector for covariates in test.dat
cov.int
a character string naming the covariate for interaction, the covariate has to be included in covar
sub
"N" (default) for no stratified analysis, and "Y" for requesting stratified analyses (only when cov.int is dichotomous)

Value

Please see value in geepack.lgst.int.batch.imputed function.

Details

Similar to the details for geepack.lgst.int.batch function but here the SNP data contains imputed genotypes (allele dosages) that are continuous and range from 0 to 2.

References

Liang, K.Y. and Zeger, S.L. (1986) Longitudinal data analysis using generalized linear models. Biometrika, 73 13--22.

Zeger, S.L. and Liang, K.Y. (1986) Longitudinal data analysis for discrete and continuous outcomes. Biometrics, 42 121--130.

Yan, J and Fine, J. (2004) Estimating equations for association structures. Stat Med, 23 859--874.

See Also

geese function from package geepack

Examples

Run this code
## Not run: 
# geepack.lgst.int.imputed(snp=data[,"rs123"],phen="CVD",test.dat=data,covar=c("age",sex"),
# cov.int="sex",sub="Y")
# ## End(Not run)

Run the code above in your browser using DataLab