lmer function from package lme4.
This function is called in glmm.lgst.batch function to apply association test to all SNPs in the
genotype data.
glmm.lgst(snp, phen, test.dat, covar = NULL, model = "a")test.dat test.dat glmm.lgst.batch.
glmm.lgst function tests association between a dichtomous trait and a SNP from a dataset that contains phenotype, genotype and
pedigree data (test.dat), where the dataset needs to be ordered by famid.
Chen MH, Liu X, Wei F, Larson MG, Fox CS, Vasan RS and Yang Q. (2011) A comparison of strategies for analyzing dichotomous outcomes in genome-wide association studies with general pedigrees. Genetic Epidemiology 35:650-657.
lmer function from package lme4 ## Not run:
# glmm.lgst(snp=data[,"rs123"],phen="CVD",test.dat=data,model="a",covar=c("age","sex"))
# ## End(Not run)
Run the code above in your browser using DataLab