Learn R Programming

GWAF (version 2.0)

geepack.lgst.int.batch.imputed: function to test gene-environment or gene-gene interaction between a dichotomous trait and a batch of imputed SNPs in families using Generalized Estimation Equation model

Description

Fit logistic regression via Generalized Estimation Equation (GEE) to test gene-environment or gene-gen interaction between a dichotomous phenotype and all imputed SNPs in a genotype file in family data under additive genetic model. The interaction term is the product of SNP genotype and a covariate for interaction (cov.int). The covariate for interaction (cov.int) can be SNP genotype (gene-gene interaction) or an environmental factor (gene-environment interaction). Only one interaction term is allowed. When cov.int is dichotomous, stratified analyses can be requested by specifying sub="Y". The covariance between the main effect (SNP) and the interaction effect is provided in the output when stratified analysis is not requested. Each family is treated as a cluster, with independence working correlation matrix used in the robust variance estimator. This function applies the same interaction test to all SNPs in the imputed genotype data. The interaction test is carried out by geepack.lgst.int.imputed function from GWAF where the the geese function from package geepack is used.

Usage

geepack.lgst.int.batch.imputed(genfile,phenfile,pedfile,outfile,phen,covars,cov.int,sub="N",
col.names=T,sep.ped=",",sep.phe=",",sep.gen=",")

Arguments

Value

No value is returned. Instead, results are written to outfile. If stratified analyses are requested, the result file will include the following columns. Otherwise, cov_beta_snp_beta_int will be included instead of the results from stratified analyses, that is, beta_snp_cov0, se_snp_cov0, pval_snp_cov0, beta_snp_cov1, se_snp_cov1, and pval_snp_cov1.phenphenotype namesnpSNP namecovar_intthe covariate for interactionnsample size used in analysisAFallele frequency of the coded allelendthe number of individuals in affected sampleAFdallele frequency of the coded allele in affected samplemodelgenetic model used in analysis, additive model onlybeta_snpregression coefficient of SNP covariatese_snpstandard error of beta_snppval_snpp-value of testing beta_snp not equal to zerobeta_snp_cov0regression coefficient of SNP covariate in stratified analysis using the subset where cov.int level is 0se_snp_cov0standard error of beta_snp_cov0pval_snp_cov0p-value of testing beta_snp_cov0 not equal to zerobeta_snp_cov1regression coefficient of SNP covariate in stratified analysis using the subset where cov.int level is 1se_snp_cov1standard error of beta_snp_cov1pval_snp_cov1p-value of testing beta_snp_cov1 not equal to zerobeta_intregression coefficient of the interaction termse_intstandard error of beta_intpval_intp-value of testing beta_int not equal to zeroremarkwarning or additional information for the analysis, 'not converged' indicates the GEE analysis did not converge; 'logistic reg' indicates GEE model is replaced by logistic regression; 'exp count<5' 5="" indicates="" any="" expected="" count="" is="" less="" than="" in="" phenotype-genotype="" table;="" 'not="" converged="" and="" exp="" count<5',="" 'logistic="" reg="" &="" count<5'="" are="" noted="" similarly;="" 'collinearity'="" collinearity="" exists="" between="" snp="" some="" covariates<="" description="">

Details

Similar to the details for geepack.lgst.int.batch but here the SNP data contains imputed genotypes (allele dosages) that are continuous and range from 0 to 2.