cov.int).
The covariate for interaction (cov.int) can be SNP genotype (gene-gene interaction) or an environmental factor (gene-environment interaction). Only one
interaction term is allowed. When cov.int is dichotomous, stratified analyses can be requested by specifying sub="Y". The covariance between the main
effect (SNP) and the interaction effect is provided in the output when stratified analysis is not requested. Each family is treated as
a cluster, with independence working correlation matrix used in the robust variance estimator.
This function is called in geepack.lgst.int.batch.imputed function to apply interaction test to all imputed SNPs in a
genotype file. The interaction test is carried out by the geese function from package geepack.
geepack.lgst.int.imputed(snp,phen,test.dat,covar,cov.int,sub="N")test.dat test.dat covar cov.int is dichotomous) geepack.lgst.int.batch.imputed function.
geepack.lgst.int.batch function but here the SNP data contains imputed genotypes (allele dosages)
that are continuous and range from 0 to 2.
Zeger, S.L. and Liang, K.Y. (1986) Longitudinal data analysis for discrete and continuous outcomes. Biometrics, 42 121--130.
Yan, J and Fine, J. (2004) Estimating equations for association structures. Stat Med, 23 859--874.
geese function from package geepack ## Not run:
# geepack.lgst.int.imputed(snp=data[,"rs123"],phen="CVD",test.dat=data,covar=c("age",sex"),
# cov.int="sex",sub="Y")
# ## End(Not run)
Run the code above in your browser using DataLab